<template>
  <div class="rightbox">
    <div class="title">
      <span>蔬菜大棚</span>
      <img src="../../../assets/img/zonlan (9).png" alt="" />
    </div>
    <div class="content">
      <div id="yield"></div>
      <div id="measure"></div>
    </div>
  </div>
</template>

<script>
export default {
  //import引入的组件需要注入到对象中才能使用
  components: {},
  data() {
    //这里存放数据
    return {
      yieldoption: {},
      measureoption: {},
    };
  },
  //方法集合
  methods: {
    leftdrawLine() {
      // 基于准备好的dom，初始化echarts实例
      let leftChart = this.$echarts.init(document.getElementById("yield"), {
        width: "400px",
        height: "400px",
      });
      var data = [78, 60, 60, 70, 69];
      var titlename = ["黄瓜", "茄子", "番茄", "甜瓜", "甜椒"];
      var valdata = [683, 234, 234, 523, 345];
      var myColor = ["#1089E7", "#F57474", "#56D0E3", "#F8B448", "#8B78F6"];
      let option = {
        baseOption: {
          backgroundColor: "rgba(0,0,0,0)",
          xAxis: {
            show: false,
          },
          title: {
            text: "农产品预计产量Top5(吨）",
            left: "center",
            textStyle: {
              color: "#fff",
            },
          },
          grid: {
            left: "15%",
            right: "2%",
            width: "80%",
            bottom: "2%",
            top: "10%",
            containLabel: true,
          },
          yAxis: [
            {
              show: true,
              data: titlename,
              inverse: true,
              axisLine: {
                show: false,
              },
              splitLine: {
                show: false,
              },
              axisTick: {
                show: false,
              },
              axisLabel: {
                textStyle: {
                  color: function (value, index) {
                    var num = myColor.length;
                    return myColor[index % num];
                  },
                },
                formatter: function (value, index) {
                  return ["{title|" + value + "} "].join("\n");
                },
                rich: {},
              },
            },
            {
              show: true,
              inverse: true,
              data: valdata,
              axisLabel: {
                textStyle: {
                  color: function (value, index) {
                    var num = myColor.length;
                    return myColor[index % num];
                  },
                },
              },
              axisLine: {
                show: false,
              },
              splitLine: {
                show: false,
              },
              axisTick: {
                show: false,
              },
            },
          ],
          series: [
            {
              name: "吨",
              type: "bar",
              yAxisIndex: 0,
              data: data,
              barWidth: 30,
              itemStyle: {
                normal: {
                  barBorderRadius: 30,
                  color: function (params) {
                    var num = myColor.length;
                    return myColor[params.dataIndex % num];
                  },
                },
              },
              label: {
                normal: {
                  show: true,
                  position: "inside",
                  formatter: "{c}%",
                },
              },
            },
          ],
        },
        media: [
          {
            query: {
              maxWidth: 2560,
            },
            option: {
              title: {
                textStyle: {
                  fontSize: 16,
                },
              },
              grid: {
                top: "10%",
                left: "15%",
                width: "80%",
                height: "80%",
                containLabel: true,
              },
              series: [
                {
                  name: "吨",
                  type: "bar",
                  yAxisIndex: 0,
                  data: data,
                  barWidth: 25,
                  // 柱之间间隔没生效
                  // barGap: "0%",
                  // barCategoryGap: "30%",

                  itemStyle: {
                    normal: {
                      barBorderRadius: 30,
                      color: function (params) {
                        var num = myColor.length;
                        return myColor[params.dataIndex % num];
                      },
                    },
                  },
                  label: {
                    normal: {
                      show: true,
                      position: "inside",
                      formatter: "{c}%",
                    },
                  },
                },
              ],
            },
          },
        ],
      };

      // 绘制图表
      leftChart.setOption(option);
    },
    rightdrawLine() {
      let rightChart = this.$echarts.init(document.getElementById("measure"), {
        width: "644px",
        height: "644px",
      });
      let option = {
        baseOption: {
          backgroundColor: "rgba(0,0,0,0)",
          title: {
            text: "农产品种植面积(Top5）",
            left: "center",
            textStyle: {
              color: "#fff",
            },
          },
          legend: {
            data: ["黄瓜", "番茄", "茄子", "甜瓜", "甜椒"],
            orient: "horizontal",
            left: "center",
            top: "10%",
            textStyle: {
              color: "#",
              fontSize: 16,
            },
          },
          tooltip: {
            trigger: "item",
            formatter: "{b} : {c} ({d}%)",
          },

          // visualMap: {
          //   show: false,
          //   min: 500,
          //   max: 600,
          //   inRange: {
          //     //colorLightness: [0, 1]
          //   },
          // },
          series: [
            {
              name: "农产品种植面积",
              type: "pie",
              radius: "38%",
              center: ["37%", "45%"],
              color: [
                "rgb(131,249,103)",
                "#FBFE27",
                "#FE5050",
                "#1DB7E5",
                "#3156E3",
              ], //'#FBFE27','rgb(11,228,96)','#FE5050'
              data: [
                {
                  value: 285,
                  name: "黄瓜",
                },
                {
                  value: 410,
                  name: "番茄",
                },
                {
                  value: 274,
                  name: "茄子",
                },
                {
                  value: 235,
                  name: "甜瓜",
                },
                {
                  value: 235,
                  name: "甜椒",
                },
              ].sort(function (a, b) {
                return a.value - b.value;
              }),
              roseType: "radius",

              label: {
                normal: {
                  formatter: ["{c|{c}}", "{b|{b}}"].join("\n"),
                  rich: {
                    c: {
                      color: "rgb(241,246,104)",
                      fontSize: 22,
                      fontWeight: "bold",
                      lineHeight: 5,
                    },
                    b: {
                      color: "rgb(98,137,169)",
                      fontSize: 15,
                      height: 40,
                    },
                  },
                },
              },
              labelLine: {
                normal: {
                  lineStyle: {
                    color: "rgb(98,137,169)",
                  },
                  smooth: 0.2,
                  length: 1,
                  length2: 1,
                },
              },
              itemStyle: {
                normal: {
                  shadowColor: "rgba(0, 0, 0, 0.8)",
                  shadowBlur: 50,
                },
              },
            },
          ],
        },
        media: [
          {
            query: {
              minWidth: 550,
            },
            option: {
              series: [
                {
                  center: ["50%", "35%"],
                  radius: "38%",
                },
              ],
            },
          },
        ],
      };
      // 绘制图表

      rightChart.setOption(option);
    },
  },
  mounted() {
    this.leftdrawLine();
    this.rightdrawLine();
  },
  created() {},
};
</script>
<style lang="less" scoped>
//@import url(); 引入公共css类
.rightbox {
  overflow: hidden;
  width: 100%;
  height: calc(50vh - 128px);
  // background-color: #bfa;
  box-sizing: border-box;

  .title {
    width: 100%;
    // height: 78px;
    // text-align: center;
    //   background: url("../../../assets/img/zonlan (9).png") no-repeat center;
    //   background-size: 100% 100%;
    // background-position: 0 30px;
    // line-height: 30px;
    position: relative;
    img {
      width: 100%;
    }
    span {
      font-size: 78px;
      font-weight: 400;
      color: #ffe86b;
      background: linear-gradient(0deg, #bce7ff 0%, #69efff 98.6572265625%);
      -webkit-background-clip: text;
      -webkit-text-fill-color: transparent;
      position: absolute;
      left: 50%;
      top: 0;
      transform: translateX(-50%);
    }
  }
  .content {
    padding-top: 40px;
    height: 80%;
    width: 100%;
    box-sizing: border-box;
    // background-color: #fff;
    display: flex;
    justify-content: space-evenly;
    align-items: center;
    #yield {
      width: 49%;
      height: 100%;
      // background-color: #fff;
    }
    #measure {
      width: 49%;
      height: 100%;
      // background-color: rgb(17, 0, 255);
    }
  }
}
@media only screen and (max-width: 2560px) {
  .rightbox {
    overflow: visible;
    width: 100%;
    height: calc(50vh - 128px);
    .content {
      display: block;
      #yield {
        width: 100%;
        height: 70%;
      }
      #measure {
        width: 100%;
        height: 100%;
      }
    }
  }
}
</style>
